@@ -24,6 +24,13 @@ class Background:
         if overwrite:
             os.system('rm -r {0}'.format(savefolder))
             print('Remove {0}'.format(savefolder))
+        else:
+            try:
+                os.chdir(savefolder)
+                print('Stop: Savefolder {0} already exists, overwrite = {1}'.format(savefolder,overwrite))
+                return
+            except:
+                pass
         tmp = os.getcwd()
         for i in savefolder.split('/'):
             os.system('mkdir {0}'.format(i))
